.. _whatsnew:

.. currentmodule:: pandas

.. ipython:: python
   :suppress:

   import numpy as np
   from pandas import *
   import pandas as pd
   randn = np.random.randn
   np.set_printoptions(precision=4, suppress=True)
   options.display.max_rows = 15

**********
What's New
**********

These are new features and improvements of note in each release.

.. include:: whatsnew/v0.19.2.txt

.. include:: whatsnew/v0.19.1.txt

.. include:: whatsnew/v0.19.0.txt

.. include:: whatsnew/v0.18.1.txt

.. include:: whatsnew/v0.18.0.txt

.. include:: whatsnew/v0.17.1.txt

.. include:: whatsnew/v0.17.0.txt

.. include:: whatsnew/v0.16.2.txt

.. include:: whatsnew/v0.16.1.txt

.. include:: whatsnew/v0.16.0.txt

.. include:: whatsnew/v0.15.2.txt

.. include:: whatsnew/v0.15.1.txt

.. include:: whatsnew/v0.15.0.txt

.. include:: whatsnew/v0.14.1.txt

.. include:: whatsnew/v0.14.0.txt

.. include:: whatsnew/v0.13.1.txt

.. include:: whatsnew/v0.13.0.txt

.. include:: whatsnew/v0.12.0.txt

.. include:: whatsnew/v0.11.0.txt

.. include:: whatsnew/v0.10.1.txt

.. include:: whatsnew/v0.10.0.txt

.. include:: whatsnew/v0.9.1.txt

.. include:: whatsnew/v0.9.0.txt

.. include:: whatsnew/v0.8.1.txt

.. include:: whatsnew/v0.8.0.txt

.. include:: whatsnew/v0.7.3.txt

.. include:: whatsnew/v0.7.2.txt

.. include:: whatsnew/v0.7.1.txt

.. include:: whatsnew/v0.7.0.txt

.. include:: whatsnew/v0.6.1.txt

.. include:: whatsnew/v0.6.0.txt

.. include:: whatsnew/v0.5.0.txt

.. include:: whatsnew/v0.4.x.txt
